@@ -1,6 +1,7 @@
 "diffQ2" <- function(xy, fct = max, fws = 8, col = 2, plot = FALSE, verbose = FALSE, 
 			 peak = FALSE, deriv = FALSE, negderiv = TRUE, derivlimits = FALSE, 
-			 derivlimitsline = FALSE, vertiline = FALSE, rsm = FALSE)
+			 derivlimitsline = FALSE, vertiline = FALSE, rsm = FALSE,
+			 inder = FALSE)
 {
 	    # Test if fws (number of neighbors) is within a meaningful range.
 	    options(warn = -1)
@@ -11,23 +12,25 @@
 	    # Calls instances of diffQ to calculate the Tm of the first and the second derivatives.
 	    # The arguments are similar to diffQ
 	    # Calculates the first derivative and provides the starting information for the second derivative.
-	    TmD1	<-	diffQ(xy, fct = fct, fws = fws, verbose = TRUE, rsm = rsm)
+	    TmD1	<-	diffQ(xy, fct = fct, fws = fws, negderiv = negderiv, verbose = TRUE, rsm = rsm, inder = inder)
 
 	    if (TmD1[["temperature"]][["mean.T.delta"]] >= 0.5) {
 
-			tmp.xy <- 	predict(smooth.spline(TmD1$xy[,1], TmD1$xy[,2]), 
-					    seq(min(TmD1$xy[,1]), max(TmD1$xy[,1]), TmD1[["temperature"]][["mean.T.delta"]] / 1.3))
+			tmp.xy <- 	predict(smooth.spline(TmD1$xy[, 1], TmD1$xy[, 2]), 
+					    seq(min(TmD1$xy[, 1]), max(TmD1$xy[, 1]), TmD1[["temperature"]][["mean.T.delta"]] / 1.3))
 			xy.smoothed <- 	data.frame(tmp.xy$x, tmp.xy$y)
-		} else (xy.smoothed <-  data.frame(TmD1$xy[,1], smooth.spline(TmD1$xy[,1], TmD1$xy[,2])$y))
+		} else (xy.smoothed <-  data.frame(TmD1$xy[, 1], smooth.spline(TmD1$xy[, 1], TmD1$xy[, 2])$y))
 
 	    # Calculates the second derivative and from the first derivative for the minimum of the melting curve.
 	    Tm1D2	<-	diffQ(xy.smoothed, fct = min, fws = fws, verbose =  TRUE, col = col, peak = peak, 
 						   deriv = deriv, negderiv = FALSE, derivlimits = derivlimits, 
-						   derivlimitsline = derivlimitsline, vertiline = vertiline)
+						   derivlimitsline = derivlimitsline, vertiline = vertiline,
+						   inder = inder)
 	    # Calculates the second derivative and from the first derivative for the maximum of the melting curve.
 	    Tm2D2	<-	diffQ(xy.smoothed, fct = max, fws = fws, verbose =  TRUE, col = col, peak = peak, 
 						   deriv = deriv, negderiv = FALSE, derivlimits = derivlimits, 
-						   derivlimitsline = derivlimitsline, vertiline = vertiline)
+						   derivlimitsline = derivlimitsline, vertiline = vertiline,
+						   inder = inder)
 	    
 	    # Vectors of the two melting temperatures of the second derivative.
 	    x <- c(Tm1D2[["Tm"]], Tm2D2[["Tm"]])
@@ -44,7 +47,7 @@
 	    if (plot) {
 	    # Plot the first derivative
 		  par(fig = c(0,1,0.475,1))
-		  plot(TmD1$xy, xlab = "T", ylab = "-d(F) / dT", type = "b")
+		  plot(TmD1$xy, xlab = "Temperature", ylab = "-d(F) / dT", type = "b")
 		    abline(v = (TmD1$Tm), col = "grey", lwd = 1.25)
 		    abline(v = (Tm1D2$Tm), col = "grey")
 		    abline(v = (Tm2D2$Tm), col = "grey")
@@ -55,7 +58,7 @@
 
 	    # Plot the second derivative
 		  par(fig = c(0,1,0,0.525), new = TRUE)
-		  plot(Tm1D2$xy, xlim = c(min(TmD1$xy[,1]), max(TmD1$xy[,1])), xlab = "T", ylab = "-d^2(F) / dT^2", type = "b")
+		  plot(Tm1D2$xy, xlim = c(min(TmD1$xy[, 1]), max(TmD1$xy[, 1])), xlab = "Temperature", ylab = "-d^2(F) / dT^2", type = "b")
 		    abline(v = (TmD1$Tm), col = "grey")
 		    points(Tm1D2$limits.xQ, Tm1D2$limits.diffQ, col = "green", pch = 19)
 		    points(Tm2D2$limits.xQ, Tm2D2$limits.diffQ, col = "blue", pch = 1)
